<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>CCanvas</name>
    <message>
        <location filename="../canvas/CCanvas.cpp" line="80"/>
        <source>No map view available.</source>
        <translation>Просмотр карты недоступен.</translation>
    </message>
</context>
<context>
    <name>CCommandProcessor</name>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="30"/>
        <source>Print debug output to console.</source>
        <translation>Вывести отладочный вывод на консоль.</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="33"/>
        <source>Print debug output to logfile (temp. path).</source>
        <translation>Вывести отладочный вывод в файл журнала (временный путь).</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="36"/>
        <source>Do not show splash screen.</source>
        <translation>Не показывайте заставку.</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="39"/>
        <source>QMapTool application locale.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="39"/>
        <source>code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="42"/>
        <source>File with QMapTool configuration.</source>
        <translation>Файл с конфигурацией QMapTool.</translation>
    </message>
    <message>
        <location filename="../setup/CCommandProcessor.cpp" line="42"/>
        <source>file</source>
        <translation>файл</translation>
    </message>
</context>
<context>
    <name>CDialogRefPoint</name>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="35"/>
        <source>bad coordinate</source>
        <translation>неверная координата</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="51"/>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="56"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="51"/>
        <source>Bad value for X pixel.</source>
        <translation>Неверное значение для X пикселя.</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="56"/>
        <source>Bad value for Y pixel.</source>
        <translation>Неверное значение для Y пикселя.</translation>
    </message>
</context>
<context>
    <name>CDrawContextPixel</name>
    <message>
        <location filename="../canvas/CDrawContextPixel.cpp" line="63"/>
        <source>Failed to load</source>
        <translation>Не удалось загрузить</translation>
    </message>
</context>
<context>
    <name>CDrawContextProj</name>
    <message>
        <location filename="../canvas/CDrawContextProj.cpp" line="59"/>
        <source>Failed to load</source>
        <translation>Не удалось загрузить</translation>
    </message>
</context>
<context>
    <name>CGdalFile</name>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="45"/>
        <location filename="../helpers/CGdalFile.cpp" line="56"/>
        <location filename="../helpers/CGdalFile.cpp" line="78"/>
        <source>Error...</source>
        <translation>Ошибка ...</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="45"/>
        <location filename="../helpers/CGdalFile.cpp" line="56"/>
        <source>Failed to load file: %1</source>
        <translation>Не удалось загрузить файл: %1</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="78"/>
        <source>File must be 8 bit palette or gray indexed.</source>
        <translation>Файл должен иметь 8-битную цветовую палитру или индекс градации серого.</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="170"/>
        <source>(color table)</source>
        <translation>(Farbtabelle)(таблица цветов)</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="174"/>
        <source>(RGB)</source>
        <translation>(RGB)</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="178"/>
        <source>(RGBA)</source>
        <translation>(RGBA)</translation>
    </message>
    <message>
        <location filename="../helpers/CGdalFile.cpp" line="182"/>
        <source>(unknown)</source>
        <translation>(неизвестно)</translation>
    </message>
</context>
<context>
    <name>CGridPlacer</name>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="33"/>
        <source>Select one of the corners and place the marker at the corresponding grid crossing on the map. All 4 corners have to be placed.</source>
        <translation>Выберите угол и поместите маркер в соответствующую точку сетки на карте. Все 4 угла должны быть установлены.</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="133"/>
        <source>Point 1 - not set</source>
        <translation>Пункт 1 - не установлен</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="135"/>
        <source>Point 1 - ok</source>
        <translation>Пункт 1 - ок</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="139"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="143"/>
        <source>Point 1 - bad</source>
        <translation>пункт 1 неверный</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="151"/>
        <source>Point 2 - ok</source>
        <translation>Пункт 2 - ок</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="155"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="159"/>
        <source>Point 2 - bad</source>
        <translation>пункт 2 неверный</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="167"/>
        <source>Point 3 - ok</source>
        <translation>Пункт 3 - ок</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="171"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="175"/>
        <source>Point 3 - bad</source>
        <translation>пункт 3 неверный</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="183"/>
        <source>Point 4 - ok</source>
        <translation>Пункт 4 - ок</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="187"/>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="191"/>
        <source>Point 4 - bad</source>
        <translation>пункт 4 неверный</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="149"/>
        <source>Point 2 - not set</source>
        <translation>Пункт 2 - не установлен</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="165"/>
        <source>Point 3 - not set</source>
        <translation>Пункт 3 - не установлен</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="181"/>
        <source>Point 4 - not set</source>
        <translation>Пункт 4 - не установлен</translation>
    </message>
</context>
<context>
    <name>CGridSelArea</name>
    <message>
        <location filename="../overlay/gridtool/CGridSelArea.cpp" line="30"/>
        <source>Select the area to be covered by the calculated reference points. Simply grab the corners of the selection rectangle with a left click and place them where you want with a second click.</source>
        <translation>Выберите область, для которой должны быть рассчитаны опорные точки. Просто щелкните по углам прямоугольника выделения левой кнопкой мышки и поместите угол в нужное место вторым щелчком мышки.</translation>
    </message>
</context>
<context>
    <name>CGridSetRef</name>
    <message>
        <location filename="../overlay/gridtool/CGridSetRef.cpp" line="37"/>
        <source>Valid coordinate formats: If the projection is lat/lon all values have to be in degree, e.g. &quot;48.2&quot; or &quot;12.4&quot;. For all other projections values are either in multiple of meter or feet. If you are doing it wrong the entry field will turn red.</source>
        <translation>Допустимые форматы координат: если проекция широта/долгота, все значения должны быть в градусах, например, «48.2» или «12.4». Для всех остальных проекций значения либо в метрах, либо в футах. Если сделать это неправильно, поле ввода станет красным.</translation>
    </message>
</context>
<context>
    <name>CHelp</name>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="42"/>
        <source>Help</source>
        <translation>Справки</translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="80"/>
        <source>Content</source>
        <translation>Содержание</translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="81"/>
        <source>Index</source>
        <translation>Индекс</translation>
    </message>
    <message>
        <location filename="../../common/help/CHelp.cpp" line="82"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
<context>
    <name>CHelpIndex</name>
    <message>
        <location filename="../../common/help/CHelpIndex.cpp" line="26"/>
        <source>Search:</source>
        <translation>Поиск:</translation>
    </message>
</context>
<context>
    <name>CHelpSearch</name>
    <message>
        <location filename="../../common/help/CHelpSearch.cpp" line="30"/>
        <source>Search:</source>
        <translation>Поиск:</translation>
    </message>
</context>
<context>
    <name>CItemListWidget</name>
    <message>
        <location filename="../items/CItemListWidget.cpp" line="86"/>
        <source>Select files...</source>
        <translation>Выбрать файлы...</translation>
    </message>
</context>
<context>
    <name>CItemMapLayer</name>
    <message>
        <location filename="../items/CItemMapLayer.cpp" line="33"/>
        <source>Layer</source>
        <translation>Слой</translation>
    </message>
</context>
<context>
    <name>CItemTreeWidget</name>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="133"/>
        <source>&lt;p&gt;The current map &lt;i&gt;&apos;%1&apos;&lt;/i&gt; does not match the projection of previous loaded maps. All map files need to have the same projection.&lt;/p&gt;&lt;p&gt;&lt;b&gt;This file&lt;/b&gt;: %2&lt;/p&gt;&lt;p&gt;&lt;b&gt;Expected&lt;/b&gt;: %3&lt;/p&gt;</source>
        <translation>&lt;p&gt;Данная карта &lt;i&gt;&apos;%1&apos;&lt;/i&gt; не соответствует проекции ранее загруженных карт. Все файлы карт должны иметь одинаковую проекцию.&lt;/p&gt;&lt;p&gt;&lt;b&gt;Этот файл: &lt;/b&gt;%2&lt;/p&gt;&lt;p&gt;&lt;b&gt; Ожидается:&lt;/b&gt;%3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="139"/>
        <source>Error...</source>
        <translation>Ошибка ...</translation>
    </message>
    <message>
        <location filename="../items/CItemTreeWidget.cpp" line="199"/>
        <source>Select files...</source>
        <translation>Выберите файлы ...</translation>
    </message>
</context>
<context>
    <name>CMainWindow</name>
    <message>
        <location filename="../misc.h" line="29"/>
        <source>File access failed...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc.h" line="30"/>
        <source>Failed to open %1 with error %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>COverlayCutMap</name>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="198"/>
        <source>Delete mask...</source>
        <translation>Удалить маску ...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="198"/>
        <source>Are you sure to delete complete mask?</source>
        <translation>Вы действительно хотите удалить всю маску?</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="214"/>
        <source>Save mask...</source>
        <translation>Сохранить маску ...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="257"/>
        <source>Load mask...</source>
        <translation>Загрузить маску ...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="269"/>
        <source>Failed...</source>
        <translation>Не удалось...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayCutMap.cpp" line="269"/>
        <source>Not a shape file.</source>
        <translation>Не файл фигуры.</translation>
    </message>
</context>
<context>
    <name>COverlayGridTool</name>
    <message>
        <location filename="../overlay/COverlayGridTool.cpp" line="33"/>
        <source>Before you proceed with &apos;ok&apos;:
Please cross check all data once again. A bad reference coordinate will ruin all the work. Also cross check if the selected area contains as many reference points as possible at the border. You can easily delete points outside the map in the Reference Tool. But it&apos;s much more effort to set additional points in case you miss some.  When you are done press &apos;ok&apos; to transfer the derived reference points to the Reference Tool.

The next step will be to use the Reference Tool to adjust the position of all reference points to the real grid position on the map.</source>
        <translation>Прежде чем продолжить с «ОК»:
Пожалуйста, еще раз перепроверьте все данные. Плохая опорная координата испортит всю работу. Также перепроверьте, содержит ли выделенная область как можно больше опорных точек на границе. Вы можете легко удалить точки за пределами карты в инструменте ссылок (реферировать карты). Гораздо больше усилий нужно приложить, чтобы установить дополнительные точки, если вы их пропустили. По окончании работы нажмите &quot;ОК&quot;, чтобы перенести полученные опорные точки в инструмент ссылок.

Следующим шагом будет использование инструмента ссылок для настройки положения всех опорных точек в соответствии с реальным положением сетки на карте.</translation>
    </message>
</context>
<context>
    <name>COverlayRefMap</name>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="43"/>
        <source>If you used the Grid Tool you have to fine tune the reference points by placing them as much as possible on the grid crossing. Be aware that if you over scale you get jumping points by rounding effects. Be precise but do not make religion out of the task.
If your mouse focus is on the map you can use the N and B keys to jump forward an backward in the reference point list. 
The is also the option to fine tune the reference points in auto-mode. In this mode the next reference point is selected automatically right after you placed the current one. This is very convenient for a large number of reference points.</source>
        <translation>Если вы использовали инструмент сетки, вам придется корректировать точки, перемещая их к точкам сетки. Имейте в виду, что при увеличении масштаба изображения точки могут прыгать из-за эффектов округления. Будьте точным при позиционировании, но не делайте религию из задачи.

Когда курсор мышки находится на карте, вы можете использовать клавиши N и B для перемещения вперед и назад в списке опорных точек.
Существует также возможность настройки опорных точек в автоматическом режиме. В этом режиме следующая опорная точка автоматически выбирается после размещения текущей точки. Эта функция очень полезна, когда вы хотите редактировать большое количество точек.</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="519"/>
        <source>Save reference points...</source>
        <translation>Сохранить опорные точки ...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="554"/>
        <source>Load reference points...</source>
        <translation>Загрузить опорные точки...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="589"/>
        <source>Delete all reference points...</source>
        <translation>Удалить все опорные точки...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="590"/>
        <source>Are you sure to delete all reference points in the list?</source>
        <translation>Вы уверены, что хотите удалить все опорные точки из списка?</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="616"/>
        <source>Delete...</source>
        <translation>Удалить...</translation>
    </message>
    <message>
        <location filename="../overlay/COverlayRefMap.cpp" line="616"/>
        <source>Delete all selected reference points?</source>
        <translation>Удалить все выделенные опорные точки?</translation>
    </message>
</context>
<context>
    <name>COverlayRefMapPoint</name>
    <message>
        <location filename="../overlay/refmap/COverlayRefMapPoint.cpp" line="40"/>
        <source>bad coordinate</source>
        <translation>неправильная координата</translation>
    </message>
</context>
<context>
    <name>CProj</name>
    <message>
        <location filename="../../common/gis/proj_x.cpp" line="153"/>
        <source>The value
&apos;%1&apos;
is not a valid coordinate system definition:
%2</source>
        <translation>Значение
&quot;%1&quot;
не является допустимым определением системы координат:
%2</translation>
    </message>
    <message>
        <location filename="../../common/gis/proj_x.cpp" line="162"/>
        <source>Lat/Lon projection is not allowed in this case.</source>
        <translation>В этом случае широта/долгота проекция не допускается.</translation>
    </message>
</context>
<context>
    <name>CProjWizard</name>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="45"/>
        <source> (Spheroid: %1)</source>
        <translation> (Сфероид: %1)</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="59"/>
        <source>north</source>
        <translation>север</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="60"/>
        <source>south</source>
        <translation>юг</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/CProjWizard.cpp" line="199"/>
        <source>Error...</source>
        <translation>Ошибка...</translation>
    </message>
</context>
<context>
    <name>CSetupExtTools</name>
    <message>
        <location filename="../setup/CSetupExtTools.cpp" line="61"/>
        <location filename="../setup/CSetupExtTools.cpp" line="62"/>
        <location filename="../setup/CSetupExtTools.cpp" line="63"/>
        <location filename="../setup/CSetupExtTools.cpp" line="64"/>
        <location filename="../setup/CSetupExtTools.cpp" line="65"/>
        <location filename="../setup/CSetupExtTools.cpp" line="66"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;не найдено&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../setup/CSetupExtTools.cpp" line="77"/>
        <source>Select %1 binary...</source>
        <translation>Выбрать программу %1 ...</translation>
    </message>
</context>
<context>
    <name>CShell</name>
    <message>
        <location filename="../shell/CShell.cpp" line="40"/>
        <source>Execution of external program `%1` failed: </source>
        <translation>Не удалось выполнить внешнюю программу `%1`: </translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="43"/>
        <source>Process cannot be started.
</source>
        <translation>Процесс не может быть запущен.
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="44"/>
        <source>Make sure the required packages are installed, `%1` exists and is executable.
</source>
        <translation>Убедитесь, что необходимые пакеты установлены, `%1` существует и является исполняемым.
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="49"/>
        <source>External process crashed.
</source>
        <translation>Сбой внешнего процесса.
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="53"/>
        <source>An unknown error occurred.
</source>
        <translation>Произошла неизвестная ошибка.
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="130"/>
        <source>!!! failed !!!
</source>
        <translation>!!! Не удалось !!!
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="143"/>
        <source>
Canceled by user&apos;s request.
</source>
        <translation>
Отменено по запросу пользователя.
</translation>
    </message>
    <message>
        <location filename="../shell/CShell.cpp" line="168"/>
        <source>!!! done !!!
</source>
        <translation>!!!Сделано!!!
</translation>
    </message>
</context>
<context>
    <name>CToolAddOverview</name>
    <message>
        <location filename="../tool/CToolAddOverview.cpp" line="29"/>
        <source>Add Overviews</source>
        <translation>Добавить обзоры</translation>
    </message>
    <message>
        <location filename="../tool/CToolAddOverview.cpp" line="32"/>
        <source>Raster map files consume quite some memory if a larger area is displayed. Pre-calculated overview levels help to speed up loading and displaying the map. These overviews can be stored within the map file as well as an external file. GDAL can remove internally stored overviews, however it will not free the used space in the file. Therefore it&apos;s size will remain large. If you do not like that use the external option.</source>
        <translation>Файлы для растровых карт занимают довольно много памяти, если отображается большая область. Предварительно рассчитанные обзоры с разными шкалами (уровнями) помогают ускорить загрузку и отрисовку карты. Эти обзоры могут быть сохранены как в файле карты, так и во внешнем файле. GDAL может убрать внутренние обзоры, однако не освободит используемое пространство в файле. Поэтому его размер останется большим. Если вам это не нравится, используйте возможность создания внешнего файла.</translation>
    </message>
</context>
<context>
    <name>CToolCutMap</name>
    <message>
        <location filename="../tool/CToolCutMap.cpp" line="29"/>
        <source>Cut Map</source>
        <translation>Вырезать карту</translation>
    </message>
    <message>
        <location filename="../tool/CToolCutMap.cpp" line="32"/>
        <source>Paper maps usually have a border you don&apos;t want to have. To combine maps seamlessly you have to cut that border, replacing it by transparent pixel. This tool allows you to define a cut line and it will add an alpha channel for transparency to your map.</source>
        <translation>Бумажные карты обычно имеют границы, которые вы не хотите иметь. Чтобы объединить карты плавно, вы должны обрезать эту границу, заменив ее прозрачными пикселями. Этот инструмент позволяет определить линию разреза и добавит альфа-канал для прозрачности карты.</translation>
    </message>
</context>
<context>
    <name>CToolExport</name>
    <message>
        <location filename="../tool/CToolExport.cpp" line="29"/>
        <source>Export Maps</source>
        <translation>Экспортировать карты</translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="33"/>
        <source>To use the maps on your device you have to export them to the proprietary format supported by the device. Depending on the device this can vary from a single layer map to a map stack with maps of different scale.</source>
        <translation>Чтобы использовать карты на вашем устройстве, вы должны экспортировать их в фирменный формат, поддерживаемый устройством. В зависимости от устройства это может варьироваться от однослойной карты до стека карт с разными масштабами.</translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="41"/>
        <source>Note: This tool will use all files in the list as a input. This will only work if all files have the same projection.</source>
        <translation>Примечание: Этот инструмент будет использовать все файлы в списке в качестве входных данных. Это будет работать только, если все файлы имеют одинаковую проекцию.</translation>
    </message>
    <message>
        <location filename="../tool/CToolExport.cpp" line="104"/>
        <source>Select filename...</source>
        <translation>Выбрать имя файла...</translation>
    </message>
</context>
<context>
    <name>CToolGrid</name>
    <message>
        <location filename="../tool/CToolGrid.cpp" line="35"/>
        <source>By placing 4 reference points at the corners of a grid square and referencing them by their top left corner, the width and height, all the other grid points can be estimated.</source>
        <translation>Поместив 4 опорные точки в углы квадрата сетки и ссылаясь на них через верхний левый угол, а также через ширину и высоту, можно приблизительно рассчитать все остальные точки сетки.</translation>
    </message>
</context>
<context>
    <name>CToolPalettize</name>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="30"/>
        <source>Add Color Palette</source>
        <translation>Добавить цветовую палитру</translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="37"/>
        <source>Usually you use RGBA color while referencing a map because the large color space allows you to scale and rotate the map without any loss of quality. But it results into rather large files. The file size can be optimized by using a color palette instead of the RGBA color space. The impact on quality is low as long as you do not want to scale or rotate the map. If you want to combine files with a color palette all files need to have the same palette.</source>
        <translation>Обычно вы используете цветы RGBA при обращении к карте, поскольку большое цветовое пространство позволяет масштабировать и поворачивать карту без потери качества. Но это приводит к довольно большим файлам. Размер файла можно оптимизировать, используя цветовую палитру вместо цветового пространства RGBA. Влияние на качество будет низким, если вы не хотите масштабировать или поворачивать карту. Если вы хотите объединить файлы с цветовой палитрой, все файлы должны иметь одинаковую палитру.</translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="49"/>
        <source>Note: This tool will use all files in the list as a combined input to derive an optimal palette. This will only work if all files have the same projection and scale.</source>
        <translation>Примечание: Этот инструмент будет использовать все файлы в списке в качестве комбинированного ввода для получения оптимальной палитры. Это будет работать только, если все файлы имеют одинаковую проекцию и масштаб.</translation>
    </message>
    <message>
        <location filename="../tool/CToolPalettize.cpp" line="114"/>
        <source>Select filename...</source>
        <translation>Выберите имя файла...</translation>
    </message>
</context>
<context>
    <name>CToolRefMap</name>
    <message>
        <location filename="../tool/CToolRefMap.cpp" line="32"/>
        <source>Reference Map</source>
        <translation>Реферировать карты</translation>
    </message>
    <message>
        <location filename="../tool/CToolRefMap.cpp" line="35"/>
        <source>A scan of a paper map can be converted to a referenced raster map if you place at least three reference points on the map. The more points the better the result. If your map has a grid you can place points on that grid with the grid tool.</source>
        <translation>Отсканированную бумажную карту можно преобразовать в эталонную растровую карту, указав на ней не менее 3 опорных точек. Чем больше точек вы поставите, тем лучше. Если ваша карта имеет сетку, вы можете использовать инструмент сетки, чтобы разместить точки на сетке.</translation>
    </message>
</context>
<context>
    <name>IAbout</name>
    <message>
        <location filename="../IAbout.ui" line="14"/>
        <source>About...</source>
        <translation>О программе....</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="26"/>
        <source>&lt;b&gt;QMapTool&lt;/b&gt;, Version</source>
        <translation>&lt;b&gt;QMapTool&lt;/b&gt;, версия</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="39"/>
        <location filename="../IAbout.ui" line="77"/>
        <location filename="../IAbout.ui" line="91"/>
        <location filename="../IAbout.ui" line="105"/>
        <source>TextLabel</source>
        <translation>Метка текста</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="70"/>
        <source>Qt</source>
        <translation>Qt</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="84"/>
        <source>GDAL</source>
        <translation>GDAL</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="98"/>
        <source>PROJ</source>
        <translation>PROJ</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="121"/>
        <source>This software is licensed under GPL3 or any later version</source>
        <translation>Это программное обеспечение лицензировано под GPL3 или любой более поздней версией</translation>
    </message>
    <message>
        <location filename="../IAbout.ui" line="128"/>
        <source>© 2017 Oliver Eichler (oliver.eichler@gmx.de)</source>
        <translation>© 2017 Oliver Eichler (oliver.eichler@gmx.de)</translation>
    </message>
</context>
<context>
    <name>ICoordFormatSetup</name>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="14"/>
        <source>Coordinate Format...</source>
        <translation>Формат координат ...</translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="24"/>
        <source>N48° 53&apos; 39.6&quot; E13° 31&apos; 6.78&quot;</source>
        <translation>N48° 53&apos; 39.6&quot; E13° 31&apos; 6.78&quot;</translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="31"/>
        <source>N48.8943° E013.51855°</source>
        <translation>N48.8943° E013.51855°</translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="38"/>
        <source>N48° 53.660 E013° 31.113</source>
        <translation>N48° 53.660 E013° 31.113</translation>
    </message>
    <message>
        <location filename="../units/ICoordFormatSetup.ui" line="53"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; For some GUI elements changing the units will not take effect until you restart QMapTool.</source>
        <translation>&lt;b&gt;Примечание:&lt;/b&gt; Изменение единиц для некоторых элементов графического пользовательского интерфейса вступят в силу только после перезапуска QMapTool.</translation>
    </message>
</context>
<context>
    <name>IDialogRefPoint</name>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалог</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="25"/>
        <source>Coord. Map File [pixel]</source>
        <translation>Координаты файла карты [пиксель]</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="32"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="42"/>
        <source>y</source>
        <translation>y</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="49"/>
        <source>Coord. lat/lon WGS84 [°]</source>
        <translation>Координаты широта / долгота WGS84 [°]</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IDialogRefPoint.ui" line="59"/>
        <source>Bad position format. Must be: 
&quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot;
or
&quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</source>
        <translation>Неправильный формат. Либо:
&quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot;
или
&quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</translation>
    </message>
</context>
<context>
    <name>IGridPlacer</name>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="150"/>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridPlacer.ui" line="224"/>
        <source>Set Area</source>
        <translation>Установка области</translation>
    </message>
</context>
<context>
    <name>IGridSelArea</name>
    <message>
        <location filename="../overlay/gridtool/IGridSelArea.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSelArea.ui" line="35"/>
        <source>TextLabel</source>
        <translation>Метка текста</translation>
    </message>
</context>
<context>
    <name>IGridSetRef</name>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="35"/>
        <source>Grid Projection:</source>
        <translation>Проекция сетки:</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="60"/>
        <source>TextLabel</source>
        <translation>Метка текста</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="72"/>
        <source>Easting</source>
        <translation>Восточная координата</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="82"/>
        <source>Horiz. Spacing</source>
        <translation>Горизонтальное расстояние</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="92"/>
        <source>Northing</source>
        <translation>Северная координата</translation>
    </message>
    <message>
        <location filename="../overlay/gridtool/IGridSetRef.ui" line="102"/>
        <source>Vert. Spacing</source>
        <translation>Вертикальное расстояние</translation>
    </message>
</context>
<context>
    <name>IItemListWidget</name>
    <message>
        <location filename="../items/IItemListWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="40"/>
        <source>Add map files to list</source>
        <translation>Добавить файлы карт в список</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="43"/>
        <location filename="../items/IItemListWidget.ui" line="60"/>
        <location filename="../items/IItemListWidget.ui" line="77"/>
        <location filename="../items/IItemListWidget.ui" line="94"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="57"/>
        <source>Remove selected file from the list.</source>
        <translation>Удалить выбранный файл из списка.</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="74"/>
        <source>Clear complete list of map files.</source>
        <translation>Удалить все файлы карты.</translation>
    </message>
    <message>
        <location filename="../items/IItemListWidget.ui" line="91"/>
        <source>Reload the currently selected map.</source>
        <translation>Перезагрузить выбранную карту.</translation>
    </message>
</context>
<context>
    <name>IItemTreeWidget</name>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="40"/>
        <source>Add map files to list</source>
        <translation>Добавить файлы карт в список</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="43"/>
        <location filename="../items/IItemTreeWidget.ui" line="60"/>
        <location filename="../items/IItemTreeWidget.ui" line="77"/>
        <location filename="../items/IItemTreeWidget.ui" line="94"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="57"/>
        <source>Remove selected file from the list.</source>
        <translation>Удалить выбранный файл из списка.</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="74"/>
        <source>Clear complete list of map files.</source>
        <translation>Удалить все файлы карты.</translation>
    </message>
    <message>
        <location filename="../items/IItemTreeWidget.ui" line="91"/>
        <source>Reload the currently selected map.</source>
        <translation>Перезагрузить выбранную карту.</translation>
    </message>
</context>
<context>
    <name>IMainWindow</name>
    <message>
        <location filename="../IMainWindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="32"/>
        <source>Setup</source>
        <translation>Настройка</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="41"/>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="47"/>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="52"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="68"/>
        <source>Tools</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="101"/>
        <source>Shell</source>
        <translation>Оболочка</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="120"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="129"/>
        <source>Ext. Tools</source>
        <translation>Настройка внешних инструментов</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="132"/>
        <source>Setup paths to external tools, like gdalwarp etc.</source>
        <translation>Настройка путей к внешним инструментам, таким как gdalwarp и т.д.</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="144"/>
        <location filename="../IMainWindow.ui" line="147"/>
        <source>Flip Mouse Wheel</source>
        <translation>Флип колесо мышки</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="156"/>
        <location filename="../IMainWindow.ui" line="159"/>
        <source>Setup Units</source>
        <translation>Настройка единиц</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="168"/>
        <source>Setup Coord. Format</source>
        <translation>Настройка формата координат</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="171"/>
        <source>Change the format coordinates are displayed</source>
        <translation>Изменить формат отображения координат</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="182"/>
        <source>Show Tool Help</source>
        <translation>Показать справку по инструменту</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="191"/>
        <source>Help</source>
        <translation>Справки</translation>
    </message>
    <message>
        <location filename="../IMainWindow.ui" line="194"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
</context>
<context>
    <name>IOverlayCutMap</name>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="35"/>
        <source>Just move the map and zoom.</source>
        <translation>Переместить карту и увеличить масштаб.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="58"/>
        <source>Add point to mask.</source>
        <translation>Добавить точку к маске.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="61"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="84"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="107"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="137"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="158"/>
        <location filename="../overlay/IOverlayCutMap.ui" line="175"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="81"/>
        <source>Move point of mask.</source>
        <translation>Переместить точку маски.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="104"/>
        <source>Remove point from mask.</source>
        <translation>Удалить точку из маски.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="134"/>
        <source>Remove complete cut mask.</source>
        <translation>Удалить полностью вырезанную маску.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="155"/>
        <source>Load cut mask from shape file.</source>
        <translation>Загрузить маску вырезания из файла фигуры.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayCutMap.ui" line="172"/>
        <source>Save cut mask to shape file.</source>
        <translation>Сохранить маску вырезания файл фигуры.</translation>
    </message>
</context>
<context>
    <name>IOverlayGridTool</name>
    <message>
        <location filename="../overlay/IOverlayGridTool.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayGridTool.ui" line="145"/>
        <source>do not translate</source>
        <translation>do not translate</translation>
    </message>
</context>
<context>
    <name>IOverlayRefMap</name>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="40"/>
        <source>Just move the map and zoom.</source>
        <translation>Переместить карту и увеличить масштаб.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="63"/>
        <source>Add reference point.</source>
        <translation>Добавить опорную точку.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="66"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="89"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="112"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="135"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="165"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="179"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="200"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="217"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="244"/>
        <location filename="../overlay/IOverlayRefMap.ui" line="326"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="86"/>
        <source>Move reference point.</source>
        <translation>Переместить опорную точку.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="109"/>
        <source>Remove single reference point.</source>
        <translation>Удалить опорную точку.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="132"/>
        <source>Move reference points with auto mode. This will pickup the next point after you moved a reference point.</source>
        <translation>Переместить опорные точки в автоматическом режиме. Это заберет следующую точку после перемещения опорной точки.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="162"/>
        <source>Remove all reference points.</source>
        <translation>Удалить все опорные точки.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="176"/>
        <source>Switch to the Grid Tool.</source>
        <translation>Переключить на инструмент сетки.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="197"/>
        <source>Load reference points from GCP file.</source>
        <translation>Загрузить опорные точки из файла GCP.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="214"/>
        <source>Save reference points into GCP file.</source>
        <translation>Сохранить опорные точки в файл GCP.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="241"/>
        <source>Sort list of reference points.</source>
        <translation>Сортировать список опорных точек.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="281"/>
        <source>(x, y)[pixel]</source>
        <translation>(х, у) [пиксель]</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="286"/>
        <source>(lat, lon)[°]</source>
        <translation>(широта, долгота) [°]</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="294"/>
        <source>TextLabel</source>
        <translation>Метка текста</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="304"/>
        <source>Final Map Projection:</source>
        <translation>Окончательная проекция карты:</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="316"/>
        <source>Enter a valid projection string. Valid strings are &quot;+proj...&quot; or &quot;EPSG:...&quot;.</source>
        <translation>Введите допустимую строку проекции. Допустимыми строками являются &quot;+proj...&quot; или &quot;EPSG:...&quot;.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="323"/>
        <source>Start projection wizard.</source>
        <translation>Запустите мастер проецирования.</translation>
    </message>
    <message>
        <location filename="../overlay/IOverlayRefMap.ui" line="343"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>IProjWizard</name>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="14"/>
        <source>PROJ Wizard</source>
        <translation>PROJ мастер</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="29"/>
        <source>Mercator</source>
        <translation>Меркатор</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="38"/>
        <source>UTM</source>
        <translation>UTM</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="45"/>
        <source>zone</source>
        <translation>Зона</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="82"/>
        <source>user defined</source>
        <translation>Задание пользователя</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="94"/>
        <source>Datum</source>
        <translation>Датум</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="104"/>
        <source>World Mercator (OSM)</source>
        <translation>World Mercator(OSM)</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="124"/>
        <source>Result:</source>
        <translation>Результат:</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="138"/>
        <source>UPS North (North Pole)</source>
        <translation>UPS Север (Северный полюс)</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="145"/>
        <source>UPS South (South Pole)</source>
        <translation>UPS Юг (Южный полюс)</translation>
    </message>
    <message>
        <location filename="../overlay/refmap/IProjWizard.ui" line="152"/>
        <source>Projection</source>
        <translation>Проекция</translation>
    </message>
</context>
<context>
    <name>ISetupExtTools</name>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="14"/>
        <source>Setup Ext. Tools</source>
        <translation>Настройка внешних инструментов</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="22"/>
        <location filename="../setup/ISetupExtTools.ui" line="64"/>
        <location filename="../setup/ISetupExtTools.ui" line="99"/>
        <location filename="../setup/ISetupExtTools.ui" line="173"/>
        <location filename="../setup/ISetupExtTools.ui" line="194"/>
        <location filename="../setup/ISetupExtTools.ui" line="257"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;не найдено&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="32"/>
        <location filename="../setup/ISetupExtTools.ui" line="53"/>
        <location filename="../setup/ISetupExtTools.ui" line="74"/>
        <location filename="../setup/ISetupExtTools.ui" line="88"/>
        <location filename="../setup/ISetupExtTools.ui" line="135"/>
        <location filename="../setup/ISetupExtTools.ui" line="149"/>
        <location filename="../setup/ISetupExtTools.ui" line="183"/>
        <location filename="../setup/ISetupExtTools.ui" line="211"/>
        <location filename="../setup/ISetupExtTools.ui" line="225"/>
        <location filename="../setup/ISetupExtTools.ui" line="239"/>
        <location filename="../setup/ISetupExtTools.ui" line="264"/>
        <location filename="../setup/ISetupExtTools.ui" line="275"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="112"/>
        <source>gdal_translate:</source>
        <translation>gdal_translate:</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="43"/>
        <source>gdalbuildvrt</source>
        <translation>gdalbuildvrt</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="166"/>
        <source>gdaladdo:</source>
        <translation>gdaladdo:</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="125"/>
        <source>gdalwarp:</source>
        <translation>gdalwarp:</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="29"/>
        <location filename="../setup/ISetupExtTools.ui" line="132"/>
        <location filename="../setup/ISetupExtTools.ui" line="180"/>
        <location filename="../setup/ISetupExtTools.ui" line="208"/>
        <location filename="../setup/ISetupExtTools.ui" line="222"/>
        <source>Setup user defined path.</source>
        <translation>Настроить пользовательский путь.</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="201"/>
        <source>qmt_rgb2pct</source>
        <translation>qmt_rgb2pct</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="50"/>
        <location filename="../setup/ISetupExtTools.ui" line="71"/>
        <location filename="../setup/ISetupExtTools.ui" line="85"/>
        <location filename="../setup/ISetupExtTools.ui" line="146"/>
        <location filename="../setup/ISetupExtTools.ui" line="236"/>
        <source>Reset user defined path setup.</source>
        <translation>Сбросить настройку пользовательского пути.</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="250"/>
        <source>qmt_map2jnx</source>
        <translation>qmt_map2jnx</translation>
    </message>
    <message>
        <location filename="../setup/ISetupExtTools.ui" line="288"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Usually QMapTool should detect all external tools by itself. If it does not, it&apos;s a bad setup and you should fix the PATH variable of your system. You can setup the paths manually, too, if you know what you are doing. But please keep in mind that GDAL needs a proper environment setup to function properly. If it&apos;s not setup properly you might get results but these can be off grid.</source>
        <translation>&lt;b&gt;Примечание:&lt;/b&gt; Обычно QMapTool должен находить все внешние инструменты самостоятельно. Если нет,, то обычно это связано с плохой настройкой, и вы должны проверить переменную PATH вашей системы. Вы также можете установить пути инструментов самостоятельно, при условии, что вы знаете, что делаете. Пожалуйста, имейте в виду, что GDAL нуждается в правильно настроенной среде для корректной работы. Если это не так, результаты могут быть достигнуты, но они могут быть смещены.</translation>
    </message>
</context>
<context>
    <name>ITimeZoneSetup</name>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="14"/>
        <source>Setup Timezone ...</source>
        <translation>Настройка часового пояса...</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="22"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="32"/>
        <source>Local</source>
        <translation>Местный</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="42"/>
        <source>Automatic</source>
        <translation>Автоматический</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="75"/>
        <source>Print date/time in </source>
        <translation>Печатать дату/время в </translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="82"/>
        <source>long format, or</source>
        <translation>длинном формате, или в</translation>
    </message>
    <message>
        <location filename="../units/ITimeZoneSetup.ui" line="92"/>
        <source>short format</source>
        <translation>сокращённом формате</translation>
    </message>
</context>
<context>
    <name>IToolAddOverview</name>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="59"/>
        <source>do not translate</source>
        <translation>do not translate</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="119"/>
        <source>:2</source>
        <translation>:2</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="126"/>
        <source>:4</source>
        <translation>:4</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="133"/>
        <source>:8</source>
        <translation>:8</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="140"/>
        <source>:16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="147"/>
        <source>:32</source>
        <translation>:32</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="154"/>
        <source>:64</source>
        <translation>:64</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="164"/>
        <source>Remove all overview levels from map file.</source>
        <translation>Удалить все обзоры из файла карты.</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="167"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="174"/>
        <source>Do not copy the overviews into the file itself. Add them as external file.</source>
        <translation>Не копировать обзоры в файл. Добавить их как внешний файл.</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="177"/>
        <source>Overview as external file</source>
        <translation>Обзор как внешний файл</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="207"/>
        <source>Start</source>
        <translation>Запуск</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="221"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="232"/>
        <source>For all files</source>
        <translation>все файлы</translation>
    </message>
    <message>
        <location filename="../tool/IToolAddOverview.ui" line="257"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdaladdo&quot; не найдено. Пожалуйста, проверьте настройки!&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>IToolCutMap</name>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="59"/>
        <source>do not translate</source>
        <translation>do not translate</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="114"/>
        <source>Output filename suffix</source>
        <translation>Суффикс имени выходного файла</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="133"/>
        <source>_cut</source>
        <translation>_cut</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="148"/>
        <source>Create overviews for result.</source>
        <translation>Создать обзоры для результата.</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="155"/>
        <source>GDAL Parameters</source>
        <translation>Параметры GDAL</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="183"/>
        <source>Start</source>
        <translation>Запуск</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="197"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="208"/>
        <source>For all files</source>
        <translation>все файлы</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="233"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdalwarp&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdalwarp&quot; не найдено. Пожалуйста, проверьте настройки!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolCutMap.ui" line="243"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdaladdo&quot; не найдено. Пожалуйста, проверьте настройки!&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>IToolExport</name>
    <message>
        <location filename="../tool/IToolExport.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="59"/>
        <location filename="../tool/IToolExport.ui" line="72"/>
        <source>do not translate</source>
        <translation>do not translate</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="83"/>
        <source>Garmin BirdsEye (*.jnx)</source>
        <translation>Garmin BirdsEye (*.jnx)</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="88"/>
        <source>TwoNav Raster (*.rmap)</source>
        <translation>TwoNav Raster (*.rmap)</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="101"/>
        <source>not implemented yet</source>
        <translation>еще не реализовано</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="112"/>
        <source>Target File</source>
        <translation>Конечный файл</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="130"/>
        <source>Start</source>
        <translation>Запуск</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="144"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="173"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;qmt_map2jnx&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;qmt_map2jnx&quot; не найдено. Пожалуйста, проверьте настройки!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolExport.ui" line="184"/>
        <source>Target Filename</source>
        <translation>Имя конечного файла</translation>
    </message>
</context>
<context>
    <name>IToolExportJnx</name>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="35"/>
        <location filename="../tool/export/IToolExportJnx.ui" line="81"/>
        <source>BirdsEye</source>
        <translation>BirdsEye</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="50"/>
        <source>Product ID</source>
        <translation>Идентификатор продукта</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="57"/>
        <source>Copyright notice</source>
        <translation>Авторские права</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="64"/>
        <location filename="../tool/export/IToolExportJnx.ui" line="95"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="71"/>
        <source>Product name</source>
        <translation>Название продукта</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="88"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="105"/>
        <source>JPEG</source>
        <translation>JPEG</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="133"/>
        <source>Quality</source>
        <translation>Качество</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="140"/>
        <source>Chroma subsampling</source>
        <translation>Цветовая субдискретизация</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="148"/>
        <source>411</source>
        <translation>411</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="153"/>
        <source>422</source>
        <translation>422</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="158"/>
        <source>444</source>
        <translation>444</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="169"/>
        <source>Device</source>
        <translation>Устройство</translation>
    </message>
    <message>
        <location filename="../tool/export/IToolExportJnx.ui" line="184"/>
        <source>Z-Order</source>
        <translation>Z-порядок</translation>
    </message>
</context>
<context>
    <name>IToolGDALGroupBox</name>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="14"/>
        <source>GroupBox</source>
        <translation>Окно группы</translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="17"/>
        <source>GDAL Parameters</source>
        <translation>Параметры GDAL</translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="50"/>
        <source>Resampling</source>
        <translation>Ресамплинг</translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="84"/>
        <source>Compression</source>
        <translation>Компрессия</translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="118"/>
        <source>Tiled</source>
        <translation>Мозаичный</translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="144"/>
        <source>x</source>
        <translation>х</translation>
    </message>
    <message>
        <location filename="../tool/IToolGDALGroupBox.ui" line="188"/>
        <source>Other:</source>
        <translation>Прочие</translation>
    </message>
</context>
<context>
    <name>IToolGrid</name>
    <message>
        <location filename="../tool/IToolGrid.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="56"/>
        <source>Grid Tool</source>
        <translation>Инструмент сетки</translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="65"/>
        <source>do not translate</source>
        <translation>do not translate</translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="99"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="110"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../tool/IToolGrid.ui" line="134"/>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
</context>
<context>
    <name>IToolOverviewGroupBox</name>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="14"/>
        <source>GroupBox</source>
        <translation>Окно группы</translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="71"/>
        <source>:2</source>
        <translation>:2</translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="78"/>
        <source>:4</source>
        <translation>:4</translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="85"/>
        <source>:8</source>
        <translation>:8</translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="92"/>
        <source>:16</source>
        <translation>:16</translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="99"/>
        <source>:32</source>
        <translation>:32</translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="106"/>
        <source>:64</source>
        <translation>:64</translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="119"/>
        <source>Do not copy the overviews into the file itself. Add them as external file.</source>
        <translation>Не копировать обзоры в сам файл. Добавьте их как внешний файл.</translation>
    </message>
    <message>
        <location filename="../tool/IToolOverviewGroupBox.ui" line="122"/>
        <source>Overview as external file</source>
        <translation>Обзор как внешний файл</translation>
    </message>
</context>
<context>
    <name>IToolPalettize</name>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="65"/>
        <location filename="../tool/IToolPalettize.ui" line="78"/>
        <source>do not translate</source>
        <translation>do not translate</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="96"/>
        <source>Single files, filename suffix</source>
        <translation>Отдельные файлы, суффикс имени файла</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="109"/>
        <source>_8bit</source>
        <translation>_8bit</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="123"/>
        <source>Combined file, filename:</source>
        <translation>Объединенный файл, имя файла:</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="135"/>
        <source>Embed result into *.vrt file.</source>
        <translation>Вставить результат в файл * .vrt.</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="142"/>
        <source>Create overviews for result.</source>
        <translation>Создать обзоры для результата.</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="149"/>
        <source>GDAL Parameter</source>
        <translation>Параметры GDAL</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="177"/>
        <source>Start</source>
        <translation>Запуск</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="191"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="220"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdaladdo&quot; не найдено. Пожалуйста, проверьте настройки!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="230"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdal_translate&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdal_translate&quot; не найдено. Пожалуйста, проверьте настройки!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="240"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;qmt_rgb2pct&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;qmt_rgb2pct&quot; не найдено. Пожалуйста, проверьте настройки!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolPalettize.ui" line="254"/>
        <source>Select filename</source>
        <translation>Выбрать имя файла</translation>
    </message>
</context>
<context>
    <name>IToolRefMap</name>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="59"/>
        <source>do not translate</source>
        <translation>do not translate</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="113"/>
        <source>Output filename suffix</source>
        <translation>Суффикс имени выходного файла</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="132"/>
        <source>_ref</source>
        <translation>_ref</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="144"/>
        <source>Embed result into *.vrt file.</source>
        <translation>Вставить результат в файл * .vrt.</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="151"/>
        <source>Create overviews for result.</source>
        <translation>Создать обзоры для результата.</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="158"/>
        <source>GDAL Parameters</source>
        <translation>Параметры GDAL</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="186"/>
        <source>Start</source>
        <translation>Запуск</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="200"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="211"/>
        <source>For all files</source>
        <translation>все файлы</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="236"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdalwarp&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdalwarp&quot; не найдено. Пожалуйста, проверьте настройки!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="246"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdal_translate&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdal_translate&quot; не найдено. Пожалуйста, проверьте настройки!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../tool/IToolRefMap.ui" line="256"/>
        <source>&lt;b style=&apos;color: red;&apos;&gt;No &quot;gdaladdo&quot; found. Please check setup!&lt;/b&gt;</source>
        <translation>&lt;b style=&apos;color: red;&apos;&gt;&quot;gdaladdo&quot; не найдено. Пожалуйста, проверьте настройки!&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>IUnit</name>
    <message>
        <location filename="../units/IUnit.cpp" line="714"/>
        <location filename="../units/IUnit.cpp" line="721"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../units/IUnit.cpp" line="715"/>
        <source>Bad position format. Must be: &quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot; or &quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</source>
        <translation>Плохой формат для позиции. Должно быть:
«[N | S] ddd mm.sss [W | E] ddd mm.sss»
или
«[N | S] ddd.ddd [W | E] ddd.ddd»</translation>
    </message>
    <message>
        <location filename="../units/IUnit.cpp" line="721"/>
        <source>Position values out of bounds. </source>
        <translation>Координаты положения вне пределов. </translation>
    </message>
</context>
<context>
    <name>IUnitsSetup</name>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="14"/>
        <source>Setup units...</source>
        <translation>Настройка единиц измерения...</translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="24"/>
        <source>Nautical</source>
        <translation>Морские</translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="31"/>
        <source>Imperial</source>
        <translation>Британские</translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="38"/>
        <source>Metric</source>
        <translation>Метрические</translation>
    </message>
    <message>
        <location filename="../units/IUnitsSetup.ui" line="53"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; For some GUI elements changing the units will not take effect until you restart QMapTool.</source>
        <translation>&lt;b&gt;Примечание:&lt;/b&gt; Изменение единиц для некоторых элементов графического пользовательского интерфейса вступят в силу только после перезапуска QMapTool.</translation>
    </message>
</context>
</TS>
